/*******************************************************************************
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.equinox.examples.simpleloaderhook;

import java.net.URL;
import java.security.ProtectionDomain;
import java.util.ArrayList;

import org.eclipse.osgi.baseadaptor.BaseData;
import org.eclipse.osgi.baseadaptor.bundlefile.BundleEntry;
import org.eclipse.osgi.baseadaptor.hooks.ClasspathManagerHook;
import org.eclipse.osgi.baseadaptor.loader.ClasspathEntry;
import org.eclipse.osgi.baseadaptor.loader.ClasspathManager;

/**
 * A simple loader hook which prints status of class/resource loads to standard out.
 */
public class SimpleLoaderHook implements ClasspathManagerHook {

	public void preFindLocalClass(String name, ClasspathManager loader) throws ClassNotFoundException {
		System.out.println("Attempting to load class " + name + " from bundle " + loader.getBaseData().getSymbolicName());
	}

	public void postFindLocalClass(String name, Class clazz, ClasspathManager loader) {
		if (clazz == null)
			System.out.println("Failed to load class " + name + " from bundle " + loader.getBaseData().getSymbolicName());
		else
			System.out.println("Successfully loaded class " + name + " from bundle " + loader.getBaseData().getSymbolicName());
	}

	public void preFindLocalResource(String name, ClasspathManager loader) {
		System.out.println("Attempting to load resource " + name + " from bundle " + loader.getBaseData().getSymbolicName());
	}

	public void postFindLocalResource(String name, URL resource, ClasspathManager loader) {
		if (resource == null)
			System.out.println("Failed to load resource " + name + " from bundle " + loader.getBaseData().getSymbolicName());
		else
			System.out.println("Successfully loaded resource" + name + " from bundle " + loader.getBaseData().getSymbolicName());
	}

	public byte[] processClass(String name, byte[] classbytes, ClasspathEntry classpathEntry, BundleEntry entry, ClasspathManager manager) {
		return null;
	}

	public void recordClassDefine(String name, Class clazz, byte[] classbytes, ClasspathEntry classpathEntry, BundleEntry entry, ClasspathManager manager) {
	}

	public boolean addClassPathEntry(ArrayList cpEntries, String cp, ClasspathManager hostloader, BaseData sourcedata, ProtectionDomain sourcedomain) {
		return false;
	}


}
